/* "Ordinary" definition */

.definition {
    margin: 12px 0;
    font-style: normal;
    text-align: justify;
}

.definition::before {
    content: "Definition. ";
    font-weight: bold;
    font-style: normal;
}

.definition::after {
    font-style: normal;
    float: right;
    content: "\25FB";
    width: 1em;
    height: 1em;
    bottom: 0;
    right: 0;
}

/* iBeamer definition */

.beamer-definition {
    width: 100%;
    margin: 0 auto;
    display: block;
    font-style: normal;
    color: black;
    border-radius: 10px;
    background-color: rgb(240, 255, 255);
    box-shadow: 5px 10px 8px #888888;

    ul li::before {
        background-color: rgb(25, 153, 196);
        border-radius: 50%;
        content: "";
        display: inline-block;
        margin-right: 5px;
        height: 10px;
        width: 10px;
    }
}

.beamer-definition::before {
    content: "Definition. ";
    font-weight: bold;
    font-style: normal;
    display: flex;
    color: white;
    border-radius: 10px 10px 0 0;
    padding: 10px 5px 5px 15px;
    background-color: rgb(25, 153, 196);
}

.beamer-definition::after {
    content: "\25FC	";
    position: absolute;
    width: 1.5em;
    height: 1.5em;
    bottom: 18px;
    right: 18px;
    color: black;
}